<?php

namespace Drupal\synpay\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Payment Gateway Gonfig.
 */
class Settings extends ConfigFormBase {

  const CONFIG_FIELDS = [
    'active',
    'test_mode',
    'test_login',
    'test_token',
    'live_login',
    'live_token',
  ];
  const CONFIG_FIELDS_ROBOKASSA = [
    'active',
    'test_mode',
    'login',
    'live_pass',
    'live_pass2',
    'test_pass',
    'test_pass2',
    'description',
  ];

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'synpay.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'synpay_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('synpay.settings');
    $manager = \Drupal::service('plugin.manager.synpay');
    $fields = [];
    foreach ($manager->getDefinitions() as $gateway => $source) {
      $synpay = $manager->createInstance($gateway);
      $label = $source['title']->getUntranslatedString();
      $form[$gateway] = [
        '#type' => 'details',
        '#title' => $label,
        '#open' => FALSE,
      ];
      $form[$gateway]["{$gateway}_test_mode"] = [
        '#type' => 'checkbox',
        '#title' => "Режим тестирования $label",
        '#default_value' => $config->get("{$gateway}_test_mode"),
      ];
      $form[$gateway]["{$gateway}_active"] = [
        '#type' => 'checkbox',
        '#title' => "Платежная система $label активна",
        '#default_value' => $config->get("{$gateway}_active"),
      ];
      foreach ($synpay->settingForm() as $key => $value) {
        $fields[] = "{$gateway}_{$key}";
        $form[$gateway][$key] = $value;
      }
    }
    // $form['active'] = [
    //   '#type' => 'checkbox',
    //   '#title' => 'Платежная система активна (для прямой оплаты)',
    //   '#default_value' => $config->get('active'),
    // ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $config = $this->config('synpay.settings');
    $values = $form_state->getValues();
    $manager = \Drupal::service('plugin.manager.synpay');
    $data = [];
    foreach ($manager->getDefinitions() as $gateway => $source) {
      foreach ($values as $key => $value) {
        if (stripos($key, "{$gateway}_") !== FALSE) {
          $data[$key] = trim($value);
          // $config->set($key, trim($value));
        }
      }
    }
    // $config->set('active', $form_state->getValue('active'));
    $config->setData($data)->save();
  }

}
